@@ -12,7 +12,6 @@ from typing import Any, Iterator, List, Optional, Tuple, Union
 import _libldap0
 from _libldap0 import LDAPError
 
-from .__about__ import __version__, __author__, __license__
 from .err import \
     PasswordPolicyChangeAfterReset, \
     PasswordPolicyExpirationWarning, \
@@ -567,7 +566,7 @@ class LDAPObject:
             dn: str,
             modlist,
             req_ctrls: Optional[RequestControls] = None,
-        ) -> List[LDAPResult]:
+        ) -> LDAPResult:
         msgid = self.modify(dn, modlist, req_ctrls)
         res = self.result(msgid, _libldap0.MSG_ALL, self.timeout)
         assert res.rtype == _libldap0.RES_MODIFY, ValueError('Wrong result type %d' % (res.rtype,))
@@ -738,16 +737,27 @@ class LDAPObject:
         ) -> LDAPResult:
         if msgid != _libldap0.RES_ANY and msgid not in self._outstanding_requests:
             raise _libldap0.NO_SUCH_OPERATION('Unexpected msgid value %s' % (msgid,))
-        res_type, res_data, res_msgid, res_ctrls = self._ldap_call(
-            self._l.result,
-            msgid,
-            all_results,
-            timeout,
-            True,
-            add_intermediates,
-            False
-        )
-        assert res_msgid == msgid, ValueError(
+        try:
+            res_type, res_data, res_msgid, res_ctrls = self._ldap_call(
+                self._l.result,
+                msgid,
+                all_results,
+                timeout,
+                True,
+                add_intermediates,
+                False
+            )
+        except LDAPError as ldap_err:
+            try:
+                err_ctrls = ldap_err.args[0]['ctrls']
+            except (IndexError, KeyError):
+                ldap_err.ctrls = None
+            else:
+                ldap_err.ctrls = decode_response_ctrls(err_ctrls, resp_ctrl_classes)
+            raise ldap_err
+        if res_type is None:
+            return
+        assert msgid == _libldap0.RES_ANY or res_msgid == msgid, ValueError(
             'Expected LDAP result with msgid %d, got %d' % (msgid, res_msgid)
         )
         if self.res_call_args:
